module Workarea
  module Factories
    module Registry
      Factories.add(self)

      def create_registry(overrides = {})
        attributes = {
          name: 'Test Registry',
        }.merge(overrides)

        attributes[:user_id] = create_user.id if attributes[:user_id].nil?
        attributes[:email] = create_user.email if attributes[:email].nil?
        Workarea::Registry.create!(attributes)
      end

      def create_registry_item(registry: nil, **overrides)
        registry ||= create_registry
        attributes = { quantity: 2 }.merge(overrides)

        if attributes[:product_id].nil?
          product = create_product
          attributes[:product_id] = product.id
          attributes[:sku] = product.variants.first.sku
        end

        registry.items.create!(attributes)
      end

      def create_checkout_with_registry_item
        create_tax_category(
          name: 'Sales Tax',
          code: '001',
          rates: [{ percentage: 0.07, country: 'US', region: 'PA' }]
        )

        registry = create_registry

        product = create_product(
          variants: [{ sku: 'SKU1', regular: 6.to_m, tax_code: '001' }]
        )

        registry_item = create_registry_item({
          registry: registry,
          product_id: product.id,
          sku: product.variants.first.sku,
          quantity: 2
        })

        create_shipping_service(
          carrier: 'UPS',
          name: 'Ground',
          service_code: '03',
          tax_code: '001',
          rates: [{ price: 7.to_m }]
        )

        post storefront.cart_items_path,
          params: {
            product_id: product.id,
            sku: product.skus.first,
            quantity: 2,
            registry_id: registry.id
          }
      end
    end
  end
end
