require 'test_helper'

module Workarea
  module Storefront
    class UserRegistriesIntegrationTest < Workarea::IntegrationTest
      setup :user, :registry, :login

      def user
        @user ||= create_user(password: 'w0rkArea!')
      end

      def registry
        @registry ||= create_registry({ user_id: @user.id })
      end

      def login
        post storefront.login_path,
          params: { email: user.email, password: 'w0rkArea!' }
      end

      def test_update
        patch storefront.users_registry_path(registry),
            params: {
              registry: {
                name: 'Changed'
              },
              registry_address: {
                first_name: 'Ben',
                last_name: 'Crouse',
                street: '22 S. 3rd St.',
                street_2: 'Second Floor',
                city: 'Philadelphia',
                region: 'PA',
                postal_code: '19106',
                country: 'US'
              }
            }

        assert_redirected_to(storefront.users_registry_path(registry))

        registry.reload
        assert_equal('Changed', registry.name)
        assert_equal(
          I18n.t('workarea.storefront.flash_messages.registry_updated'),
          flash[:success]
        )
      end
    end
  end
end
