require 'test_helper'

module Workarea
  module Storefront
    class UserRegistryItemsIntegrationTest < Workarea::IntegrationTest
      setup :user, :registry, :product, :login

      def user
        @user ||= create_user(password: 'w0rkArea!')
      end

      def registry
        @registry ||= create_registry({ user_id: @user.id })
      end

      def product
        @product ||= create_product(id: 'PROD1', variants: [{ sku: 'SKU1' }])
      end

      def login
        post storefront.login_path,
             params: { email: user.email, password: 'w0rkArea!' }
      end

      def test_create
        post storefront.users_registry_items_path,
             params: {
               registry_id: registry.id,
               product_id: product.id,
               sku: product.variants.first.sku,
               quantity: 2
            }

        assert_redirected_to(storefront.users_registry_path(registry))
        assert_equal(
          t('workarea.storefront.flash_messages.registry_item_created'),
          flash[:success]
        )

        item = registry.reload.items.first
        assert_equal(product.id, item.product_id)
        assert_equal(product.variants.first.sku, item.sku)
        assert_equal(2, item.quantity)
      end

      def test_update
        item = registry.items.create!(
          product_id: 'PROD1',
          sku: 'SKU1',
          quantity: 2
        )

        patch storefront.users_registry_item_path(registry, item),
             params: { product_id: 'PROD1', sku: 'SKU1', quantity: 1 }

        assert_redirected_to(storefront.users_registry_path(registry))
        assert_equal(
          t('workarea.storefront.flash_messages.registry_item_updated'),
          flash[:success]
        )

        item = registry.reload.items.first
        assert_equal('PROD1', item.product_id)
        assert_equal('SKU1', item.sku)
        assert_equal(1, item.quantity)
      end

      def test_destroy
        item = registry.items.create!(
          product_id: 'PROD1',
          sku: 'SKU1',
          quantity: 2,
        )

        delete storefront.users_registry_item_path(registry, item)

        assert_redirected_to(storefront.users_registry_path(registry))
        assert_equal(
          t('workarea.storefront.flash_messages.registry_item_destroyed'),
          flash[:success]
        )

        assert_equal(0, registry.reload.items.count)
      end

      def test_cannot_destroy_purchased_items
        item = registry.items.create!(
          product_id: 'PROD1',
          sku: 'SKU1',
          quantity: 2,
          received: 1
        )

        delete storefront.users_registry_item_path(registry, item)

        assert_redirected_to(storefront.users_registry_path(registry))
        assert_equal(
          t('workarea.storefront.flash_messages.registry_item_not_destroyed'),
          flash[:error]
        )

        assert_equal(1, registry.reload.items.count)
      end
    end
  end
end
