require 'test_helper'

module Workarea
  class RegistryTest < TestCase
    setup :registry, :product, :registry_item

    def registry
      @registry ||= create_registry
    end

    def product
      @product ||= create_product(
        name: 'Integration Product',
        variants: [
          { sku: 'SKU1', regular: 5.to_m },
          { sku: 'SKU2', regular: 6.to_m }
        ]
      )
    end

    def registry_item
      @registry_item = create_registry_item({
        registry: registry,
        product_id: product.id,
        sku: product.variants.first.sku
      })
    end

    def order
      @order ||= Workarea::Order.new(email: 'test@workarea.com')
    end

    def test_with_items
      assert_equal(1, registry.items.size)

      second_registry_item = create_registry_item({
        registry: registry,
        product_id: product.id,
        sku: product.variants.last.sku
      })

      assert_equal(2, registry.items.size)
    end

    def test_update_item
      registry.update_item(
        registry.items.first.id,
        quantity: 3
      )

      assert_equal(3, registry.items.first.quantity)
    end

    def test_remove_item
      assert_equal(1, registry.items.count)

      assert(registry.remove_item('fake_id'))
      assert_equal(1, registry.items.count)

      assert(registry.remove_item(registry.items.first.id))
      assert_equal(0, registry.items.count)
    end

    def test_public
      registry.update_attributes(privacy: 'public')

      assert(registry.public?)
      refute(registry.shared?)
      refute(registry.private?)
    end

    def test_shared
      registry.update_attributes(privacy: 'shared')

      refute(registry.public?)
      assert(registry.shared?)
      refute(registry.private?)
    end

    def test_private
      registry.update_attributes(privacy: 'private')

      refute(registry.public?)
      refute(registry.shared?)
      assert(registry.private?)
    end

    def test_mark_item_received
      order_item = order.items.build(product_id: product.id, sku: product.variants.first.sku, quantity: 1)

      registry.mark_item_received(order_item)

      assert_equal(1, registry.items.count)
      assert_equal(1, registry.items.first.received)
    end

    def test_add_purchased_registry_item
      order_item = order.items.build(product_id: product.id, sku: product.variants.first.sku, quantity: 1)

      registry.add_purchased_item({
        sku: order_item.sku,
        product_id: order_item.product_id,
        quantity: order_item.quantity,
        purchased_by: order.email
      })

      assert(2, registry.items.count)
      assert('test@workarea.com', registry.items.last.purchased_by)
      assert(1, registry.unpurchased_items)
      assert(1, registry.purchased_items)
    end
  end
end
