require 'test_helper'

module Workarea
  class UpdateRegistryItemsTest < TestCase
    setup :registry, :product, :registry_item

    def registry
      @registry ||= create_registry
    end

    def product
      @product ||= create_product(
        name: 'Integration Product',
        variants: [
          { sku: 'SKU1', regular: 5.to_m },
          { sku: 'SKU2', regular: 6.to_m }
        ]
      )
    end

    def registry_item
      @registry_item = create_registry_item({
        registry: registry,
        product_id: product.id,
        sku: product.variants.first.sku
      })
    end

    def test_perform
      user = create_user
      order = create_order(email: user.email, user_id: user.id)
      item_price = Workarea::Pricing::Sku.find('SKU1').regular_price
      order.items.build(
        product_id: product.id,
        sku: product.variants.first.sku,
        quantity: 1,
        registry_id: registry.id,
        total_price: item_price
      )
      order.save!

      UpdateRegistryItems.new.perform(order.id)

      registry.reload

      assert_equal(2, registry.items.count)
      assert_equal(1, registry.items.first.received)
      assert(registry.items.first.received?)
      assert(registry.items.last.purchased?)
      assert_equal(500, registry.items.last.total_price.cents)
    end
  end
end
